package org.infinispan.loaders.jpa.test;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

public class EntityManagerFactoryRegistry {
	private static final EntityManagerFactoryRegistry INSTANCE = new EntityManagerFactoryRegistry();
	
	private Map<String, EntityManagerFactory> registry = new HashMap<String, EntityManagerFactory>();
	public Map<String, Long> usage =  new HashMap<String, Long>();
	
	private EntityManagerFactoryRegistry() {
	}
	
	public EntityManagerFactory getEntityManagerFactory(String persistenceUnitName) {
		synchronized (registry) {
			if (!registry.containsKey(persistenceUnitName)) {
				EntityManagerFactory emf = Persistence.createEntityManagerFactory(persistenceUnitName);
				registry.put(persistenceUnitName, emf);	
			}
			
			incrementUsage(persistenceUnitName);
			return registry.get(persistenceUnitName);
		}
	}
	
	public void closeEntityManagerFactory(String persistenceUnitName) {
		synchronized (registry) {
			if (!registry.containsKey(persistenceUnitName)) {
				return;
			}
			
			decrementUsage(persistenceUnitName);
			if (getUsage(persistenceUnitName) == 0) {
				EntityManagerFactory emf = registry.remove(persistenceUnitName);
				emf.close();
			}
		}
	}
	
	protected void incrementUsage(String persistenceUnitName) {
		synchronized (usage) {
			if (usage.containsKey(persistenceUnitName))
				usage.put(persistenceUnitName, usage.get(persistenceUnitName) + 1);
			else
				usage.put(persistenceUnitName, 1L);
		}
	}
	
	protected void decrementUsage(String persistenceUnitName) {
		synchronized (usage) {
			if (usage.containsKey(persistenceUnitName)) {
				long x = usage.get(persistenceUnitName);
				if (x > 0)
					usage.put(persistenceUnitName, x - 1);
			}
		}
	}
	
	protected long getUsage(String persistenceUnitName) {
		synchronized (usage) {
			if (usage.containsKey(persistenceUnitName))
				return usage.get(persistenceUnitName);
			else
				return 0;
		}
	}
	
	public static EntityManagerFactoryRegistry getInstance() {
		return INSTANCE;
	}
	
}
