/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010 Red Hat Inc. and/or its affiliates and other
 * contributors as indicated by the @author tags. All rights reserved.
 * See the copyright.txt in the distribution for a full listing of
 * individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 * 
 */
package org.infinispan.loaders.jpa.config;

import java.io.IOException;

import org.infinispan.Cache;
import org.infinispan.configuration.cache.Configuration;
import org.infinispan.configuration.cache.ConfigurationBuilder;
import org.infinispan.configuration.global.GlobalConfiguration;
import org.infinispan.configuration.global.GlobalConfigurationBuilder;
import org.infinispan.loaders.jpa.test.JpaCacheStore;
import org.infinispan.loaders.jpa.entity.ReferenceTable;
import org.infinispan.loaders.jpa.entity.Users;
import org.infinispan.loaders.jpa.entity.Vehicle;
import org.infinispan.loaders.jpa.entity.VehicleId;
import org.infinispan.manager.DefaultCacheManager;
import org.infinispan.manager.EmbeddedCacheManager;


public class ConfigurationTest {

	public void testJavaConfig() {
		GlobalConfiguration globalConfig = new GlobalConfigurationBuilder()
				.globalJmxStatistics().transport().defaultTransport().build();

		Configuration cacheConfig = new ConfigurationBuilder().
				loaders().addStore()
				.cacheStore(new JpaCacheStore())
				.addProperty("persistenceUnitName",
						"org.infinispan.loaders.jpa")
				.addProperty("entityClassName",
						"org.infinispan.loaders.jpa.entity.User")
				.build();

		EmbeddedCacheManager cacheManager = new DefaultCacheManager(
				globalConfig);

		cacheManager.defineConfiguration("userCache", cacheConfig);
		
		cacheManager.start();
		Cache<String, Users> userCache = cacheManager.getCache("userCache");
		Users user = new Users();
		user.setUsername("rayt");
		user.setFirstName("Ray");
		user.setLastName("Tsang");
		userCache.put(user.getUsername(), user);
		userCache.stop();
	}
	
	public void testXmlConfig() throws IOException {
		EmbeddedCacheManager cacheManager = new DefaultCacheManager("config/jpa-config.xml");
		Cache<String, Users> userCache = cacheManager.getCache("userCache");
		Users user = new Users();
		user.setUsername("jdoe");
		user.setFirstName("John");
		user.setLastName("Doe");
		userCache.put(user.getUsername(), user);
		
//		Cache<String, ReferenceTable> docCache = cacheManager.getCache("documentCache");
//		ReferenceTable doc = new ReferenceTable();
//		doc.setName("hello");
//		doc.setTitle("Hello World");
//		doc.setArticle("hello there... this is a test");
//		docCache.put(doc.getTableName(), doc);
		
		Cache<VehicleId, Vehicle> vehicleCache = cacheManager.getCache("vehicleCache");
		Vehicle v = new Vehicle();
		v.setId(new VehicleId("CA", "123456"));
		v.setColor("RED");
		vehicleCache.put(v.getId(), v);
		
		userCache.stop();
	}
}
